@@ -2,6 +2,7 @@
 
 import os
 import sys
+
 from base64 import b64encode
 from functools import wraps
 from getpass import getpass
@@ -11,6 +12,7 @@ import peewee
 import argh
 from argh.decorators import aliases, arg
 
+from tmc import conf
 from tmc import api
 from tmc.errors import (APIError, NoCourseSelected, NoExerciseSelected,
                         TMCError, TMCExit)
@@ -95,7 +97,8 @@ def check_for_updates():
 @arg("-u", "--username", help="Username to be used.")
 @arg("-p", "--password", help="Password to be used.")
 @arg("-i", "--id", dest="tid", help="Course ID to be used.")
-@arg("-a", "--auto", action="store_true", help="Don't prompt for download path, use default instead")
+@arg("-a", "--auto", action="store_true",
+     help="Don't prompt for download path, use default instead")
 @false_exit
 def configure(server=None, username=None, password=None, tid=None, auto=False):
     """
@@ -327,14 +330,29 @@ def submit(course, tid=None, pastebin=False, review=False):
         return submit_exercise(sel, pastebin=pastebin, request_review=review)
 
 
+@aliases("pa")
+@arg("-i", "--id", dest="tid", help="Submit this ID.")
+@arg("-r", "--review", default=False, action="store_true",
+     help="Request a review for this submission.")
+def paste(tid=None, review=False):
+    """
+    Sends the selected exercise to the TMC pastebin.
+    """
+    submit(pastebin=True, tid=tid, review=False)
+
+
 @aliases("te")
 @arg("-i", "--id", dest="tid", help="Test this ID.")
+@arg("-t", "--time", action="store_true",
+     help="Output elapsed time at each test.")
 @selected_course
 @false_exit
-def test(course, tid=None):
+def test(course, tid=None, time=None):
     """
     Run tests on the selected exercise.
     """
+    if time is not None:
+        conf.tests_show_time = time
     if tid is not None:
         return run_test(Exercise.byid(tid))
     else:
@@ -469,9 +487,9 @@ def should_update():
     import calendar
 
     current_version = StrictVersion(__version__)
-    last_value = Config.has_name("needs_update") \
-        and Config.get_value("needs_update") == "1"
-    last_version = (0,0,0)
+    last_value = (Config.has_name("needs_update")
+                  and Config.get_value("needs_update") == "1")
+    last_version = (0, 0, 0)
     if Config.has_name("last_version"):
         last_version = StrictVersion(Config.get_value("last_version"))
 
@@ -505,8 +523,8 @@ def should_update():
 
 
 commands = [select, update, download, test, submit, skip, current, previous,
-            reset, configure, version, list_all, run, check_for_updates]
-
+            reset, configure, version, list_all, run, check_for_updates,
+            paste]
 
 def main():
     parser = argh.ArghParser()
