@@ -14,7 +14,7 @@ class CheckTest(BaseTest):
 
     def test(self, exercise):
         _, _, err = self.run(["make", "clean", "all", "run-test"], exercise)
-        ret = TestResult()
+        ret = []
 
         testpath = path.join(exercise.path(), "test", "tmc_test_results.xml")
         if not path.isfile(testpath):
@@ -23,10 +23,12 @@ class CheckTest(BaseTest):
         ns = "{http://check.sourceforge.net/ns}"
         root = ET.parse(testpath).getroot()
         for test in root.iter(ns + "test"):
+            success = True
+            name = test.find(ns + "description").text
+            message = None
             if test.get("result") == "failure":
-                ret.success = False
-                ret.error += test.find(ns + "message").text + "\n"
-            else:
-                ret.successes += test.find(ns + "description").text + "\n"
+                success = False
+                message = test.find(ns + "message").text
+            ret.append(TestResult(success=success, name=name, message=message))
 
         return ret
